@@ -24,7 +24,9 @@
 
 #define NUM_OF_CHARS 256
 
-#include <iostream.h>
+#include <iostream>
+
+using std::ostream;
 
 class CharTranslator
 {
