@@ -1,7 +1,9 @@
 #ifndef _FILEUTIL_H
 #define _FILEUTIL_H
 
-#include <iostream.h>
+#include <iostream>
+
+using std::istream;
 
 char *read_file(char *fileName);
 char *createOutputFileName( char *inputFileName, char *outputDir );
