@@ -53,6 +53,7 @@ extern int prolog_scanner_lex() ;
 extern int perl_scanner_lex() ;
 extern int php3_scanner_lex() ;
 extern int python_scanner_lex() ;
+extern int ruby_scanner_lex() ;
 extern int flex_scanner_lex() ;
 extern int changelog_scanner_lex() ;
 
@@ -155,6 +156,8 @@ processFile( char *source_language, char *output_format,
     php3_scanner_lex ();
   else if (strcmp (source_language, "python") == 0)
     python_scanner_lex ();
+  else if (strcmp (source_language, "ruby") == 0)
+    ruby_scanner_lex ();
   else if (strcmp (source_language, "flex") == 0)
     flex_scanner_lex ();
   else if (strcmp (source_language, "changelog") == 0)
