@@ -24,17 +24,23 @@
 
 static Messages *_messager = 0 ;
 
-void printMessage( char *s, ostream &stream ) {
+void printMessage( const char *s, ostream &stream ) {
   if ( _messager )
     _messager->printMessage(s,stream) ;
 }
 
-void printWarning( char *s, ostream &stream ) {
+void
+printMessage_noln( const char *s, ostream &stream ) {
+  if ( _messager )
+    _messager->printMessage_noln(s,stream) ;
+}
+
+void printWarning( const char *s, ostream &stream ) {
   if ( _messager )
     _messager->printWarning(s,stream) ;
 }
 
-void printError( char *s, ostream &stream ) {
+void printError( const char *s, ostream &stream ) {
   if ( _messager )
     _messager->printError(s,stream) ;
 }
