@@ -24,6 +24,11 @@
 #include "colors.h"
 #include "keys.h"
 
+#include <iostream>
+
+using std::cerr;
+using std::endl;
+
 Tags *GlobalTags = 0 ;
 
 void setTags( Tags *t ) {
